@@ -1,7 +1,5 @@
 # frozen_string_literal: true
 
-require 'securerandom'
-
 module Gitlab
   class Experiment
     module Cookies
@@ -34,7 +32,7 @@ module Gitlab
 
         cookie ||= SecureRandom.uuid
         cookie_jar.permanent.signed[cookie_name] = {
-          value: cookie, secure: true, domain: domain, httponly: true
+          value: cookie, secure: Configuration.secure_cookie, domain: domain, httponly: true
         }
 
         hash.merge(key => cookie)
